@@ -226,56 +226,68 @@ class TDECORE_EXPORT TDEGlobalSettings
      */
     static KMouseSettings & mouseSettings();
 
-    /**
-     * The path to the desktop directory of the current user.
-     * @return the user's desktop directory
-     */
-    static TQString desktopPath() { initStatic(); return *s_desktopPath; }
-
     /**
      * The path to the autostart directory of the current user.
      * @return the path of the autostart directory
      */
-    static TQString autostartPath() { initStatic(); return *s_autostartPath; }
+    static TQString autostartPath() { initPaths(); return *s_autostartPath; }
 
     /**
      * DEPRECATED (starting from kde-3.4).
      * This isn't where the trash contents is, anymore.
      * Use TDEIO::trash() to trash files, "trash:/" to list the trash contents.
      */
-    static TQString trashPath() { initStatic(); return *s_trashPath; }
+    static TQString trashPath() { initPaths(); return *s_trashPath; }
     // KDE4: if you want to remove the above, move it to kdesktop/init.cc, which needs
     // to know the old location of the trash
 
+    /**
+     * The path to the desktop directory of the current user.
+     * @return the user's desktop directory
+     */
+    static TQString desktopPath() { initPaths(); return *s_desktopPath; }
+
     /**
      * The path where documents are stored of the current user.
      * @return the path of the document directory
      */
-    static TQString documentPath() { initStatic(); return *s_documentPath; }
-
-    /**
-     * The path where documents are stored of the current user.
-     * @return the path of the videos directory
-     */
-    static TQString videosPath() { initStatic(); return *s_videosPath; }
-
-    /**
-     * The path where documents are stored of the current user.
-     * @return the path of the music directory
-     */
-    static TQString musicPath() { initStatic(); return *s_musicPath; }
+    static TQString documentPath() { initPaths(); return *s_documentPath; }
 
     /**
      * The path where documents are stored of the current user.
      * @return the path of the downloads directory
      */
-    static TQString downloadPath() { initStatic(); return *s_downloadPath; }
+    static TQString downloadPath() { initPaths(); return *s_downloadPath; }
+
+    /**
+     * The path where documents are stored of the current user.
+     * @return the path of the music directory
+     */
+    static TQString musicPath() { initPaths(); return *s_musicPath; }
 
     /**
      * The path where documents are stored of the current user.
      * @return the path of the pictures directory
      */
-    static TQString picturesPath() { initStatic(); return *s_picturesPath; }
+    static TQString picturesPath() { initPaths(); return *s_picturesPath; }
+
+    /**
+     * The path of the public share of the current user.
+     * @return the path of the public share directory
+     */
+    static TQString publicSharePath() { initPaths(); return *s_publicSharePath; }
+
+    /**
+     * The path where templates are stored of the current user.
+     * @return the path of the templates directory
+     */
+    static TQString templatesPath() { initPaths(); return *s_templatesPath; }
+
+    /**
+     * The path where documents are stored of the current user.
+     * @return the path of the videos directory
+     */
+    static TQString videosPath() { initPaths(); return *s_videosPath; }
 
     /**
      * The default color to use when highlighting toolbar buttons.
@@ -558,9 +570,15 @@ class TDECORE_EXPORT TDEGlobalSettings
 
 private:
     /**
-     * reads in all paths from kdeglobals
+     * global initialization - should only include paths initialization
+     *
+     * The method is primarily to ensure backward compatibility of the API.
      */
     static void initStatic();
+    /**
+     * reads in all paths from kdeglobals
+     */
+    static void initPaths();
     /**
      * initialize colors
      */
@@ -579,14 +597,16 @@ private:
     static void rereadMouseSettings();
 
 
-    static TQString* s_desktopPath;
-    static TQString* s_autostartPath;
-    static TQString* s_trashPath;
-    static TQString* s_documentPath;
-    static TQString* s_picturesPath;
-    static TQString* s_downloadPath;
-    static TQString* s_musicPath;
-    static TQString* s_videosPath;
+    static TQString *s_desktopPath;
+    static TQString *s_autostartPath;
+    static TQString *s_trashPath;
+    static TQString *s_documentPath;
+    static TQString *s_picturesPath;
+    static TQString *s_templatesPath;
+    static TQString *s_publicSharePath;
+    static TQString *s_downloadPath;
+    static TQString *s_musicPath;
+    static TQString *s_videosPath;
     static TQFont *_generalFont;
     static TQFont *_fixedFont;
     static TQFont *_toolBarFont;
@@ -594,15 +614,15 @@ private:
     static TQFont *_windowTitleFont;
     static TQFont *_taskbarFont;
     static TQFont *_largeFont;
-    static TQColor * _trinity4Blue;
-    static TQColor * _inactiveBackground;
-    static TQColor * _inactiveForeground;
-    static TQColor * _activeBackground;
-    static TQColor * _buttonBackground;
-    static TQColor * _selectBackground;
-    static TQColor * _linkColor;
-    static TQColor * _visitedLinkColor;
-    static TQColor * alternateColor;
+    static TQColor *_trinity4Blue;
+    static TQColor *_inactiveBackground;
+    static TQColor *_inactiveForeground;
+    static TQColor *_activeBackground;
+    static TQColor *_buttonBackground;
+    static TQColor *_selectBackground;
+    static TQColor *_linkColor;
+    static TQColor *_visitedLinkColor;
+    static TQColor *alternateColor;
     static KMouseSettings *s_mouseSettings;
 
     friend class TDEApplication;
